@@ -3,16 +3,18 @@ Contains Marktlokation class
 and corresponding marshmallow schema for de-/serialization
 """
 
-import attrs
-from marshmallow import fields
-from marshmallow_enum import EnumField  # type:ignore[import]
 
-from bo4e.bo.geschaeftsobjekt import Geschaeftsobjekt, GeschaeftsobjektSchema
-from bo4e.bo.geschaeftspartner import Geschaeftspartner, GeschaeftspartnerSchema
-from bo4e.com.adresse import Adresse, AdresseSchema
-from bo4e.com.geokoordinaten import Geokoordinaten, GeokoordinatenSchema
-from bo4e.com.katasteradresse import Katasteradresse, KatasteradresseSchema
-from bo4e.com.messlokationszuordnung import Messlokationszuordnung, MesslokationszuordnungSchema
+# pylint: disable=too-many-instance-attributes, too-few-public-methods
+from typing import Any, Dict, Optional
+
+from pydantic import validator
+
+from bo4e.bo.geschaeftsobjekt import Geschaeftsobjekt
+from bo4e.bo.geschaeftspartner import Geschaeftspartner
+from bo4e.com.adresse import Adresse
+from bo4e.com.geokoordinaten import Geokoordinaten
+from bo4e.com.katasteradresse import Katasteradresse
+from bo4e.com.messlokationszuordnung import Messlokationszuordnung
 from bo4e.enum.bilanzierungsmethode import Bilanzierungsmethode
 from bo4e.enum.botyp import BoTyp
 from bo4e.enum.energierichtung import Energierichtung
@@ -24,21 +26,24 @@ from bo4e.enum.verbrauchsart import Verbrauchsart
 from bo4e.validators import validate_marktlokations_id
 
 
-# pylint: disable=too-many-instance-attributes, too-few-public-methods
-@attrs.define(auto_attribs=True, kw_only=True)
 class Marktlokation(Geschaeftsobjekt):
     """
     Object containing information about a Marktlokation
 
+    .. raw:: html
+
+        <object data="../_static/images/bo4e/bo/Marktlokation.svg" type="image/svg+xml"></object>
+
     .. HINT::
-        `Marktlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/MarktlokationSchema.json>`_
+        `Marktlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/Marktlokation.json>`_
 
     """
 
     # required attributes
-    bo_typ: BoTyp = attrs.field(default=BoTyp.MARKTLOKATION)
+    bo_typ: BoTyp = BoTyp.MARKTLOKATION
     #: Identifikationsnummer einer Marktlokation, an der Energie entweder verbraucht, oder erzeugt wird.
-    marktlokations_id: str = attrs.field(validator=validate_marktlokations_id)
+    marktlokations_id: str
+    _marktlokations_id_check = validator("marktlokations_id", allow_reuse=True)(validate_marktlokations_id)
     #: Sparte der Marktlokation, z.B. Gas oder Strom
     sparte: Sparte
     #: Kennzeichnung, ob Energie eingespeist oder entnommen (ausgespeist) wird
@@ -54,24 +59,24 @@ class Marktlokation(Geschaeftsobjekt):
 
     # optional attributes
     #: Verbrauchsart der Marktlokation.
-    verbrauchsart: Verbrauchsart = attrs.field(default=None)
+    verbrauchsart: Optional[Verbrauchsart] = None
     #: Gibt an, ob es sich um eine unterbrechbare Belieferung handelt
-    unterbrechbar: bool = attrs.field(default=None)
+    unterbrechbar: Optional[bool] = None
     #: Codenummer des Netzbetreibers, an dessen Netz diese Marktlokation angeschlossen ist.
-    netzbetreibercodenr: str = attrs.field(default=None)
+    netzbetreibercodenr: Optional[str] = None
     #: Typ des Netzgebietes, z.B. Verteilnetz
-    gebietstyp: Gebiettyp = attrs.field(default=None)
+    gebietstyp: Optional[Gebiettyp] = None
     #: Die ID des Gebietes in der ene't-Datenbank
-    netzgebietsnr: str = attrs.field(default=None)  # todo: rename to "id" (see 2021-12-15 update)
+    netzgebietsnr: Optional[str] = None  # todo: rename to "id" (see 2021-12-15 update)
     #: Bilanzierungsgebiet, dem das Netzgebiet zugeordnet ist - im Falle eines Strom Netzes
-    bilanzierungsgebiet: str = attrs.field(default=None)
+    bilanzierungsgebiet: Optional[str] = None
     #: Codenummer des Grundversorgers, der für diese Marktlokation zuständig ist
-    grundversorgercodenr: str = attrs.field(default=None)
+    grundversorgercodenr: Optional[str] = None
     #: Die Gasqualität in diesem Netzgebiet. H-Gas oder L-Gas. Im Falle eines Gas-Netzes
-    gasqualitaet: Gasqualitaet = attrs.field(default=None)
+    gasqualitaet: Optional[Gasqualitaet] = None
     #: Geschäftspartner, dem diese Marktlokation gehört
-    endkunde: Geschaeftspartner = attrs.field(default=None)
-    zugehoerige_messlokation: Messlokationszuordnung = attrs.field(default=None)  # todo: rename to plural
+    endkunde: Optional[Geschaeftspartner] = None
+    zugehoerige_messlokation: Optional[Messlokationszuordnung] = None  # todo: rename to plural
     """
     Aufzählung der Messlokationen, die zu dieser Marktlokation gehören.
     Es können 3 verschiedene Konstrukte auftreten:
@@ -96,13 +101,13 @@ class Marktlokation(Geschaeftsobjekt):
 
     # only one of the following three optional attributes can be set
     #: Die Adresse, an der die Energie-Lieferung oder -Einspeisung erfolgt
-    lokationsadresse: Adresse = attrs.field(default=None)
-    geoadresse: Geokoordinaten = attrs.field(default=None)
+    lokationsadresse: Optional[Adresse] = None
+    geoadresse: Optional[Geokoordinaten] = None
     """
     Alternativ zu einer postalischen Adresse kann hier ein Ort mittels Geokoordinaten angegeben werden
     (z.B. zur Identifikation von Sendemasten).
     """
-    katasterinformation: Katasteradresse = attrs.field(default=None)
+    katasterinformation: Optional[Katasteradresse] = None
     """
     Alternativ zu einer postalischen Adresse und Geokoordinaten kann hier eine Ortsangabe mittels Gemarkung und
     Flurstück erfolgen.
@@ -110,54 +115,18 @@ class Marktlokation(Geschaeftsobjekt):
 
     # todo: add kundengruppe
 
-    # pylint:disable=unused-argument
-    @lokationsadresse.validator
-    @geoadresse.validator
-    @katasterinformation.validator
-    def validate_address_info(self, address_attribute, value):
+    # pylint:disable=unused-argument, no-self-argument
+    @validator("katasterinformation", always=True)
+    def validate_address_info(
+        cls, katasterinformation: Optional[Katasteradresse], values: Dict[str, Any]
+    ) -> Optional[Katasteradresse]:
         """Checks that there is one and only one valid adress given."""
         all_address_attributes = [
-            self.lokationsadresse,
-            self.geoadresse,
-            self.katasterinformation,
+            values["lokationsadresse"],
+            values["geoadresse"],
+            katasterinformation,
         ]
         amount_of_given_address_infos = len([i for i in all_address_attributes if i is not None])
         if amount_of_given_address_infos != 1:
             raise ValueError("No or more than one address information is given.")
-
-
-class MarktlokationSchema(GeschaeftsobjektSchema):
-    """
-    Schema for de-/serialization of Marktlokation.
-    Inherits from GeschaeftsobjektSchema.
-    """
-
-    # class_name is needed to use the correct schema for deserialisation.
-    # see function `deserialize` in geschaeftsobjekt.py
-    class_name = Marktlokation
-
-    # required attributes
-    marktlokations_id = fields.Str(data_key="marktlokationsId")
-    sparte = EnumField(Sparte)
-    energierichtung = EnumField(Energierichtung)
-    bilanzierungsmethode = EnumField(Bilanzierungsmethode)
-    netzebene = EnumField(Netzebene)
-
-    # optional attributes
-    verbrauchsart = EnumField(Verbrauchsart, load_default=None)
-    unterbrechbar = fields.Bool(load_default=None)
-    netzbetreibercodenr = fields.Str(load_default=None)
-    gebietstyp = EnumField(Gebiettyp, load_default=None)
-    netzgebietsnr = fields.Str(load_default=None)
-    bilanzierungsgebiet = fields.Str(load_default=None)
-    grundversorgercodenr = fields.Str(load_default=None)
-    gasqualitaet = EnumField(Gasqualitaet, load_default=None)
-    endkunde = fields.Nested(GeschaeftspartnerSchema, load_default=None)
-    zugehoerige_messlokation = fields.List(
-        fields.Nested(MesslokationszuordnungSchema), load_default=None, data_key="zugehoerigeMesslokation"
-    )
-
-    # only one of the following three optional attributes can be set
-    lokationsadresse = fields.Nested(AdresseSchema, load_default=None)
-    geoadresse = fields.Nested(GeokoordinatenSchema, load_default=None)
-    katasterinformation = fields.Nested(KatasteradresseSchema, load_default=None)
+        return katasterinformation
