@@ -1,9 +1,9 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.buendelvertrag import Buendelvertrag
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_vertrag import TestVertrag  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_vertrag import TestVertrag
 
 
 class TestBuendelvertrag:
