@@ -1,7 +1,7 @@
 from decimal import Decimal
 from typing import Tuple
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.geschaeftspartner import Geschaeftspartner
